==> huaweicloudsdkcss-3.1.133-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/update_es_listener_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateEsListenerResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'listener': 'EsListenerResponse'
    }

    attribute_map = {
        'listener': 'listener'
    }

    def __init__(self, listener=None):
        """UpdateEsListenerResponse

        The model defined in huaweicloud sdk

        :param listener: 
        :type listener: :class:`huaweicloudsdkcss.v1.EsListenerResponse`
        """
        
        super(UpdateEsListenerResponse, self).__init__()

        self._listener = None
        self.discriminator = None

        if listener is not None:
            self.listener = listener

    @property
    def listener(self):
        """Gets the listener of this UpdateEsListenerResponse.

        :return: The listener of this UpdateEsListenerResponse.
        :rtype: :class:`huaweicloudsdkcss.v1.EsListenerResponse`
        """
        return self._listener

    @listener.setter
    def listener(self, listener):
        """Sets the listener of this UpdateEsListenerResponse.

        :param listener: The listener of this UpdateEsListenerResponse.
        :type listener: :class:`huaweicloudsdkcss.v1.EsListenerResponse`
        """
        self._listener = listener

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEsListenerResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcss-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/update_es_listener_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateEsListenerResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'listener': 'EsListenerResponse'
    }

    attribute_map = {
        'listener': 'listener'
    }

    def __init__(self, listener=None):
        r"""UpdateEsListenerResponse

        The model defined in huaweicloud sdk

        :param listener: 
        :type listener: :class:`huaweicloudsdkcss.v1.EsListenerResponse`
        """
        
        super(UpdateEsListenerResponse, self).__init__()

        self._listener = None
        self.discriminator = None

        if listener is not None:
            self.listener = listener

    @property
    def listener(self):
        r"""Gets the listener of this UpdateEsListenerResponse.

        :return: The listener of this UpdateEsListenerResponse.
        :rtype: :class:`huaweicloudsdkcss.v1.EsListenerResponse`
        """
        return self._listener

    @listener.setter
    def listener(self, listener):
        r"""Sets the listener of this UpdateEsListenerResponse.

        :param listener: The listener of this UpdateEsListenerResponse.
        :type listener: :class:`huaweicloudsdkcss.v1.EsListenerResponse`
        """
        self._listener = listener

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEsListenerResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
